@@ -2,6 +2,7 @@
 # Copyright (C) PyZMQ Developers
 # Distributed under the terms of the Modified BSD License.
 
+import copy
 import time
 import warnings
 
@@ -173,7 +174,6 @@ class TestSocket(BaseZMQTestCase):
         "test set/getsockopt roundtrip."
         p = self.context.socket(zmq.PUB)
         self.sockets.append(p)
-        self.assertEqual(p.getsockopt(zmq.LINGER), -1)
         p.setsockopt(zmq.LINGER, 11)
         self.assertEqual(p.getsockopt(zmq.LINGER), 11)
     
@@ -194,6 +194,15 @@ class TestSocket(BaseZMQTestCase):
         s = b.recv_unicode(encoding='utf16')
         self.assertEqual(s,u)
     
+    def test_send_multipart_check_type(self):
+        "check type on all frames in send_multipart"
+        a,b = self.create_bound_pair(zmq.PAIR, zmq.PAIR)
+        self.sockets.extend([a,b])
+        self.assertRaises(TypeError, a.send_multipart, [b'a', 5])
+        a.send_multipart([b'b'])
+        rcvd = b.recv_multipart()
+        self.assertEqual(rcvd, [b'b'])
+    
     @skip_pypy
     def test_tracker(self):
         "test the MessageTracker object for tracking when zmq is done with a buffer"
@@ -383,6 +392,16 @@ class TestSocket(BaseZMQTestCase):
                     pass
             s.close()
     
+    def test_copy(self):
+        s = self.socket(zmq.PUB)
+        scopy = copy.copy(s)
+        sdcopy = copy.deepcopy(s)
+        self.assert_(scopy._shadow)
+        self.assert_(sdcopy._shadow)
+        self.assertEqual(s.underlying, scopy.underlying)
+        self.assertEqual(s.underlying, sdcopy.underlying)
+        s.close()
+    
     def test_shadow(self):
         p = self.socket(zmq.PUSH)
         p.bind("tcp://127.0.0.1:5555")
